# ContainerImagesResponseContainerImages

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cuda_version** | **str** |  |
**_datetime** | **str** |  |
**env_image_name** | **str** |  |
**env_image_tag** | **str** |  |
**environment_name** | **str** |  |
**environment_type** | **str** |  |
**image_analysis_url** | **str** |  |
**image_sha** | **str** |  |
**os_name** | **str** |  |
**os_version** | **str** |  |
**package_extract_document_id** | **str** |  |
**python_version** | **str** |  |
**quay_repo_url** | **str** |  |
**thoth_image_name** | **str** |  |
**thoth_image_version** | **str** |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

